package com.zsc.edu.gateway.modules.iot.device.service.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zsc.edu.gateway.exception.ConstraintException;
import com.zsc.edu.gateway.exception.OutlineException;
import com.zsc.edu.gateway.framework.redis.RedisUtils;
import com.zsc.edu.gateway.modules.iot.device.dto.BatchDeviceDto;
import com.zsc.edu.gateway.modules.iot.device.dto.DeviceDto;
import com.zsc.edu.gateway.modules.iot.device.dto.DeviceServeDto;
import com.zsc.edu.gateway.modules.iot.device.entity.Device;
import com.zsc.edu.gateway.modules.iot.device.mapper.DeviceMapper;
import com.zsc.edu.gateway.modules.iot.device.query.DeviceQuery;
import com.zsc.edu.gateway.modules.iot.device.repo.DeviceRepository;
import com.zsc.edu.gateway.modules.iot.device.service.DeviceService;
import com.zsc.edu.gateway.modules.iot.product.entity.Product;
import com.zsc.edu.gateway.modules.iot.product.repo.ProductRepository;
import jakarta.annotation.Resource;
import lombok.AllArgsConstructor;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author 15864
 */
@Slf4j
@Service
//@RequiredArgsConstructor
public class DeviceServiceImpl extends ServiceImpl<DeviceRepository, Device> implements DeviceService {

    //    @Value("${gatherer.version}")
//    private String gatherer;
    @Resource
    private DeviceMapper mapper;
    @Resource
    private ProductRepository productRepo;
    @Resource
    private RedisUtils redisUtils;


    /**
     * 新建设备
     */
    @Override
    public Device create(DeviceDto dto) {
        if (baseMapper.findByName(dto.getName()) == null) {
            throw new ConstraintException("该设备已存在！");
        }
        Device device = mapper.toEntity(dto);
        save(device);
        return device;
    }


    /**
     * 批量新增
     */
    @Override
    public List<Device> batchCreate(BatchDeviceDto dto) {
        List<Device> devices = new ArrayList<>();
        Product product = productRepo.selectById(dto.getProductId());
        if (product == null) {
            throw new ConstraintException("该产品不存在！");
        }
        String[] names = new String[dto.getNum()];
        for (int i = 0; i < dto.getNum(); i++) {
            String name = String.format("%s%05d", dto.getPrefix(), i + 1);
            names[i] = name;
            DeviceDto deviceDto = new DeviceDto();
            deviceDto.setName(name);
            deviceDto.setProductId(product.getId());
            deviceDto.setExtendParams(dto.getExtendParams());
            deviceDto.setProperties(dto.getProperties());
            deviceDto.setFirmwareVersion(dto.getFirmwareVersion());
            Device device = mapper.toEntity(deviceDto);
            Integer typeCode = Integer.valueOf(product.getType());
            device.setClientId(String.format("%s%02d%02d%05d", "001", typeCode, 3, i + 1));
        }

        if (!findByNameIn(names).isEmpty()) {
            throw new ConstraintException("设备已存在！");
        }

        baseMapper.insert(devices);
        return devices;
    }

    public List<Product> findByNameIn(String[] names) {
        LambdaQueryWrapper<Product> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Product::getName, names);
        return productRepo.selectList(queryWrapper);
    }

    /**
     * 更新设备
     */
    @Override
    public Device update(DeviceDto dto, Long id) {
        Device device = baseMapper.selectById(id);
        if (!device.getName().equals(dto.getName())) {
            throw new ConstraintException("deviceName", dto.getName(), "设备名称已存在");
        }
        mapper.convert(dto, device);
        String clientId = device.getClientId();
        if (redisUtils.hasKey("record:device:properties:" + clientId)) {
            redisUtils.set("record:device:properties:" + clientId, String.valueOf(JSONObject.parseObject(device.getProperties())));
        }
        save(device);
        return device;
    }

    /**
     * 分页查询设备
     *
     * @param query 查询表单
     * @param page  分页参数
     */
    @Override
    public IPage<Device> page(Page<Device> page, DeviceQuery query) {
        return baseMapper.page(page, query);
    }

    /**
     * 通过Id查找设备详情
     *
     * @param id
     * @return 设备详情
     */
    @Override
    public Device detail(Long id) {
        return baseMapper.selectById(id);
    }


//    /**
//     * 批量删除
//     *
//     * @param ids 编号数组
//     * @return
//     */
//    public Long[] batchDelete(Long[] ids) {
//        repo.deleteAllByIdInBatch(Arrays.asList(ids));
//        return ids;
//    }

    /**
     * 物模型配置的服务
     *
     * @param dto
     * @return
     */
    @Override
    public Boolean serve(DeviceServeDto dto) {
        Device device = baseMapper.findByClientIdAndStateAndOnline(dto.clientId, Device.Status.ACTIVATED, true);
        if (device != null) {
            JSONObject json = (JSONObject) JSON.toJSON(dto);
            json.put("type", "serve");
            // amqpTemplate.convertAndSend(exchange, "send", json);
            redisUtils.set("serve:sendTime:" + dto.serveName + ":" + dto.clientId, String.valueOf(new Date()));
            return true;
        } else {
            throw new OutlineException("设备[" + dto.clientId + "]不在线！");
        }

    }
}
